function [D,D_sum,D_spar,D_sper,D_epar,D_eper] = LorentzModel(Th,Tc,d,w0,f,g,ec)
%main program
%input: Hot Temp [K], Cold Temp [K], distance [m], 
%resonance frequency [cm^-1], f, g, core permittivity
%output: (array of arrays) Distance array [m], 
%total heat transfer [W/(m^2 K)], 
%heat transfer from parallel propogating term [W/(m^2 K)], 
%heat transfer from perpendicular propogating term [W/(m^2 K)], 
%heat transfer from parallel exponential term [W/(m^2 K)], 
%heat transfer from perpendicular exponential term [W/(m^2 K)]


A=1; %for W/(m^2*K)
%A=.00258; %for W/K

d_spar=[];
d_sper=[];
d_epar=[];
d_eper=[];

[w0 f g ec]


for i=1:length(d)
    d(i);
    d_spar(i)=Intspar(d(i),Th,Tc,w0,f,g,ec);
    d_sper(i)=Intsper(d(i),Th,Tc,w0,f,g,ec);
    d_epar(i)=Intepar(d(i),Th,Tc,w0,f,g,ec);
    d_eper(i)=Inteper(d(i),Th,Tc,w0,f,g,ec);
end

d_sum=d_spar+d_sper+d_epar+d_eper;

D=d; 
D_sum=d_sum;
D_spar=d_spar;
D_sper=d_sper;
D_epar=d_epar;
D_eper=d_eper;

%--------------------------------------------------------------------

function result = epsi(w,w0,f,g,ec)
%input: array of frequencies,
%resonance frequency, f, g, core permittivity
%output: array of complex epsi values

%Lorentz Model
nu=w./(2.*pi.*3E10);
result=ec + f.*(w0.^2)./(w0.^2-nu.^2+i.*nu.*g*w0);

%--------------------------------------------------------------------

function result = Intspar(d,Th,Tc,w0,f,g,ec)
%input:(one number) distance, Hot Temp, Cold Temp,
%resonance frequency, f, g, core permittivity
%output: heat transfer value for that distance for Spar

c=3E8;
b=2.89777E-3;

%number of w integration steps
nw=1000;
%up_wlim=5E14;
up_wlim=4*2*pi*c*Th/b;
w=linspace(1,up_wlim,nw);
dw=(up_wlim - 1)./nw;
Iw=[];
%number of k integration steps
nk=1000;

for j=1:length(w),
    up_klim=w(j)/c;
    k=linspace(1,up_klim,nk);
    dk=(up_klim - 1)./nk;

    Ik=dk.* (k)./(4.*pi.^2) .* Ispar(k,w(j),d,w0,f,g,ec) .* Dtheta(w(j),Th,Tc);
    Iw(j)=sum(Ik);
    %j
end
result=sum(dw.*Iw);

%--------------------------------------------------------------------

function result = Intsper(d,Th,Tc,w0,f,g,ec)
%input:(one number) distance, Hot Temp, Cold Temp,
%resonance frequency, f, g, core permittivity
%output: heat transfer value for that distance for Sper

c=3E8;
b=2.89777E-3;

%number of w integration steps
nw=1000;
%up_wlim=5E14;
up_wlim=4*2*pi*c*Th/b;
w=linspace(1,up_wlim,nw);
dw=(up_wlim - 1)./nw;
Iw=[];
%number of k integration steps
nk=1000;

for j=1:length(w),
    up_klim=w(j)/c;
    k=linspace(1,up_klim,nk);
    dk=(up_klim - 1)./nk;

    Ik=dk.* (k)./(4.*pi.^2) .* Isper(k,w(j),d,w0,f,g,ec) .* Dtheta(w(j),Th,Tc);
    Iw(j)=sum(Ik);
    %j
end
result=sum(dw.*Iw);

%--------------------------------------------------------------------

function result = Intepar(d,Th,Tc,w0,f,g,ec)
%input: (one number) distance, Hot Temp, Cold Temp,
%resonance frequency, f, g, core permittivity
%output: heat transfer value for that distance for Epar

c=3E8;
b=2.89777E-3;

%number of w integration steps
nw=1000;
%up_wlim=5E14;
up_wlim=4*2*pi*c*Th/b;
w=linspace(1,up_wlim,nw);
dw=(up_wlim - 1)./nw;
Iw=[];
%number of k integration steps
nk=1000;

for j=1:length(w),
    up_klim=klimepar(w(j),d,w0,f,g,ec);
    k=linspace(1,up_klim,nk);
    dk=(up_klim - 1)./nk;

    Ik=dk.* (k)./(4.*pi.^2) .* Iepar(k,w(j),d,w0,f,g,ec) .* Dtheta(w(j),Th,Tc);
    Iw(j)=sum(Ik);
    %j
end
result=sum(dw.*Iw);

%--------------------------------------------------------------------

function result = Inteper(d,Th,Tc,w0,f,g,ec)
%input: (one number) distance, Hot Temp, Cold Temp,
%resonance frequency, f, g, core permittivity
%output: heat transfer value for that distance for Eper

c=3E8;
b=2.89777E-3;

%number of w integration steps
nw=1000;
%up_wlim=5E14;
up_wlim=4*2*pi*c*Th/b;
w=linspace(1,up_wlim,nw);
dw=(up_wlim - 1)./nw;
Iw=[];
%number of k integration steps
nk=1000;

for j=1:length(w),
    up_klim=klimeper(w(j),d,w0,f,g,ec);
    k=linspace(1,up_klim,nk);
    dk=(up_klim - 1)./nk;

    Ik=dk.* (k)./(4.*pi.^2) .* Ieper(k,w(j),d,w0,f,g,ec) .* Dtheta(w(j),Th,Tc);
    Iw(j)=sum(Ik);
    %j
end
%[M,Ind]=max(Iw);
%result=w(Ind);
%plot(w,Iw)
result=sum(dw.*Iw);


%--------------------------------------------------------------------

function result = klimepar(w,d,w0,f,g,ec)
%input: array of frequencies and distances,
%resonance frequency, f, g, core permittivity
%output: array of wavenumber limits for Iepar

k=1;
I0=Iepar(1,w,d,w0,f,g,ec);

for j= 7:-1:4,
    while (Iepar(k,w,d,w0,f,g,ec)>.001.*I0)
        k=k+10.^j;
    end
    k=k-10.^j;
end
k=k+10.^j;
result=k;

%--------------------------------------------------------------------

function result = klimeper(w,d,w0,f,g,ec)
%input: array of frequencies and distances,
%resonance frequency, f, g, core permittivity
%output: array of wavenumber limits for Ieper

k=1;
I0=Ieper(1,w,d,w0,f,g,ec);

for j= 7:-1:4,
    while (Ieper(k,w,d,w0,f,g,ec)>.001.*I0)
        k=k+10.^j;
    end
    k=k-10.^j;
end
k=k+10.^j;
result=k;

%--------------------------------------------------------------------

function result = Ispar(kx,w,d,w0,f,g,ec)
%input: array of xdir wavenumbers, frequencies, and distance,
%resonance frequency, f, g, core permittivity
%output: array of integrand for the sine parallel portion

CR=Rpar(kx,w,w0,f,g,ec);
CB=Bpar(kx,w,w0,f,g,ec);
Ckzv=kzv(kx,w,w0,f,g,ec);

result=( (1-CR).^2 )./( abs(1-CR.*exp(i.*(CB-2.*Ckzv.*d))).^2 );

%--------------------------------------------------------------------

function result = Isper(kx,w,d,w0,f,g,ec)
%input: array of xdir wavenumbers, frequencies, and distance,
%resonance frequency, f, g, core permittivity
%output: array of integrand for the sine perpendicular portion

CR=Rper(kx,w,w0,f,g,ec);
CB=Bper(kx,w,w0,f,g,ec);
Ckzv=kzv(kx,w,w0,f,g,ec);

result=( (1-CR).^2 )./( abs(1-CR.*exp(i.*(CB-2.*Ckzv.*d))).^2 );

%--------------------------------------------------------------------

function result = Iepar(k,w,d,w0,f,g,ec)
%input: array of xdir wavenumbers, frequencies, and distance,
%resonance frequency, f, g, core permittivity
%output: array of integrand for the exponential parallel portion

Ckz=kz2(k,w,w0,f,g,ec);
Cep=epsi(w,w0,f,g,ec);

result=( real(Cep.*conj(Ckz))./abs(Cep.*Ckz) ).^2 ./ ...
    ( abs(cosh(k.*d) + i./2.*( (Ckz)./(Cep.*k) - (Cep.*k)./(Ckz) ).*sinh(k.*d)) ).^2;

%--------------------------------------------------------------------

function result = Ieper(k,w,d,w0,f,g,ec)
%input: array of xdir wavenumbers, frequencies, and distance,
%resonance frequency, f, g, core permittivity
%output: array of integrand for the exponential perpendicular portion

Ckz=kz2(k,w,w0,f,g,ec);

result=( real(Ckz)./abs(Ckz) ).^2 ./ ...
    ( abs(cosh(k.*d) + i./2.*( (Ckz)./(k) - (k)./(Ckz) ).*sinh(k.*d)) ).^2;

%--------------------------------------------------------------------

function result = Dtheta(w,Th,Tc)
%input: array of frequencies
%output: array of Planck Function

hbar=1.05457E-34;
kB=1.38065E-23;

%Differential Planck Function
%result=(hbar.^2.*w.^2)./(kB.*Th.^2) .* ( exp((hbar.*w)./(kB.*Th)) )./( (exp((hbar.*w)./(kB.*Th))-1).^2 );

%Jump in temperature Planck Function
result=( (hbar.*w)./(exp((hbar.*w)./(kB.*Th))-1) - (hbar.*w)./(exp((hbar.*w)./(kB.*Tc))-1) )./(Th-Tc);

%--------------------------------------------------------------------


function result = Rpar(kx,w,w0,f,g,ec)
%input: array of xdir wavenumbers and frequencies,
%resonance frequency, f, g, core permittivity
%output: array of Reflection coeffients for the parallel portion

Cep=epsi(w,w0,f,g,ec);
Ckz=kz(kx,w,w0,f,g,ec);
Ckzv=kzv(kx,w,w0,f,g,ec);

result=abs( (Cep.*Ckzv-Ckz)./(Cep.*Ckzv+Ckz) ).^2;

%--------------------------------------------------------------------

function result = Rper(kx,w,w0,f,g,ec)
%input: array of xdir wavenumbers and frequencies,
%resonance frequency, f, g, core permittivity
%output: array of Reflection coeffients for the perpendicular portion

Ckz=kz(kx,w,w0,f,g,ec);
Ckzv=kzv(kx,w,w0,f,g,ec);

result=abs( (Ckzv-Ckz)./(Ckzv+Ckz) ).^2;

%--------------------------------------------------------------------

function result = kzv(kx,w,w0,f,g,ec)
%input: array of xdir wavenumbers and frequencies,
%resonance frequency, f, g, core permittivity
%output: array of zdir wavenumbers in vacuum

c=3E8;

result=sqrt( (w.^2)./(c.^2) - kx.^2 );

%--------------------------------------------------------------------

function result = kz(kx,w,w0,f,g,ec)
%input: array of xdir wavenumbers and frequencies,
%resonance frequency, f, g, core permittivity
%output: array of zdir wavenumbers

c=3E8;

result=sqrt( (epsi(w,w0,f,g,ec).*w.^2)./(c.^2) - kx.^2 );

%--------------------------------------------------------------------

function result = kz2(k,w,w0,f,g,ec)
%input: array of wavenumbers and frequencies,
%resonance frequency, f, g, core permittivity
%output: array of zdir wavenumbers for exponential portion

c=3E8;

result=sqrt( ((epsi(w,w0,f,g,ec)-1).*w.^2)./(c.^2) - k.^2 );

%--------------------------------------------------------------------

function result = Bpar(kx,w,w0,f,g,ec)
%input: array of xdir wavenumbers and frequencies,
%resonance frequency, f, g, core permittivity
%output: array of beta angles for the parallel portion

Cep=epsi(w,w0,f,g,ec);
Ckz=kz(kx,w,w0,f,g,ec);
Ckzv=kzv(kx,w,w0,f,g,ec);

result=2 .* angle( (Cep.*Ckzv-Ckz).*conj(Cep.*Ckzv+Ckz) );

%--------------------------------------------------------------------

function result = Bper(kx,w,w0,f,g,ec)
%input: array of xdir wavenumbers and frequencies,
%resonance frequency, f, g, core permittivity
%output: array of beta angles for the perpendicular portion

Ckz=kz(kx,w,w0,f,g,ec);
Ckzv=kzv(kx,w,w0,f,g,ec);

result=2 .* angle( (Ckzv-Ckz).*conj(Ckzv+Ckz) );




